@@ -15,8 +15,8 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along with
- *  this program; if not, write to the Free Software Foundation, Inc., 675 Mass
- *  Ave, Cambridge, MA 02139, USA.
+ *  this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
  *
  */
 
@@ -47,6 +47,7 @@ void display_help();
 typedef struct /* nwipe_options_t */
 {
 	int            autonuke;  /* Do not prompt the user for confirmation when set.          */
+	int            noblank;   /* Do not perform a final blanking pass.                      */
 	char*          banner;    /* The product banner shown on the top line of the screen.    */
 //	nwipe_method_t method;    /* A function pointer to the wipe method that will be used.   */
 	void*          method;    /* A function pointer to the wipe method that will be used.   */
